@@ -27,7 +27,7 @@ trayIcon = egg.trayicon.TrayIcon("BiDiTrayIcon")
 
 def on_button_clicked(obj):
 	inText = clip.wait_for_text()
-	outText = pyfribidi.log2vis (inText, "ON")
+	outText = pyfribidi.log2vis (inText, pyfribidi.ON)
 	clip.set_text(outText)
 
 button.connect("clicked", on_button_clicked)
